@@ -1,4 +1,3 @@
-from datetime import datetime
 from typing import TypedDict
 
 from yelp_fetcher._util import fetch_soup
@@ -15,7 +14,6 @@ class Metadata(TypedDict):
     name: str
     city: str
     review_count: str
-    last_updated: str
 
 
 def fetch_metadata(user_id: str) -> Metadata:
@@ -26,5 +24,4 @@ def fetch_metadata(user_id: str) -> Metadata:
         name=get_user_name(user_soup),
         city=get_user_city(user_soup),
         review_count=get_user_review_count(user_soup),
-        last_updated=datetime.now().isoformat(),
     )
